@@ -1,5 +1,5 @@
 from pass_import.formats.csv import CSV
-from pass_import.formats.json import JSON, PIF
+from pass_import.formats.json import JSON
 from pass_import.formats.kdbx import KDBX
 from pass_import.formats.otp import OTP
 from pass_import.formats.xml import HTML, XML
